@@ -290,12 +290,12 @@ when \\[ess-toggle-S-assign-key] is called.")
 ;;         (setq indent (current-indentation)))
 ;;        (t
 ;;         (skip-chars-forward " \t")
-;;         (cond ((and ess-fancy-comments ;; ### or #!
+;;         (cond ((and ess-indent-with-fancy-comments ;; ### or #!
 ;;                     (or (looking-at "###")
 ;;                         (and (looking-at "#!") (= 1 (line-number-at-pos)))))
 ;;                (setq indent 0))
 ;;               ;; Single # comment
-;;               ((and ess-fancy-comments
+;;               ((and ess-indent-with-fancy-comments
 ;;                     (looking-at "#") (not (looking-at "##")))
 ;;                (setq indent comment-column))
 ;;               (t
@@ -309,7 +309,7 @@ when \\[ess-toggle-S-assign-key] is called.")
 ;;                      ((= (following-char) ?})
 ;;                       (setq indent
 ;;                             (+ indent
-;;                                (- ess-close-brace-offset ess-indent-level))))
+;;                                (- ess-close-brace-offset ess-indent-offset))))
 ;;                      ((= (following-char) ?{)
 ;;                       (setq indent (+ indent ess-brace-offset))))))))
 ;;     (skip-chars-forward " \t")
@@ -427,14 +427,14 @@ when \\[ess-toggle-S-assign-key] is called.")
 ;;               ;; If no previous statement,
 ;;               ;; indent it relative to line brace is on.
 ;;               ;; For open brace in column zero, don't let statement
-;;               ;; start there too.  If ess-indent-level is zero, use
+;;               ;; start there too.  If ess-indent-offset is zero, use
 ;;               ;; ess-brace-offset + ess-continued-statement-offset
 ;;               ;; instead.
 ;;               ;; For open-braces not the first thing in a line,
 ;;               ;; add in ess-brace-imaginary-offset.
-;;               (+ (if (and (bolp) (zerop ess-indent-level))
+;;               (+ (if (and (bolp) (zerop ess-indent-offset))
 ;;                      (+ ess-brace-offset ess-continued-statement-offset)
-;;                    ess-indent-level)
+;;                    ess-indent-offset)
 ;;                  ;; Move back over whitespace before the openbrace.
 ;;                  ;; If openbrace is not first nonwhite thing on the line,
 ;;                  ;; add the ess-brace-imaginary-offset.
@@ -864,8 +864,7 @@ and I need to relearn emacs lisp (but I had to, anyway."
       (progn
         (require 'speedbar)
         (when (featurep 'speedbar)
-          (message "enabling speedbar support")
-
+	  
           (defun S-speedbar-buttons (buffer)
             "attempted hack."
 
