@@ -21,9 +21,9 @@
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 
-;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; A copy of the GNU General Public License is available at
+;; http://www.r-project.org/Licenses/
+
 
 ;;; Commentary:
 
@@ -277,11 +277,11 @@ clean even if the buffer is \\[read-only]."
            ))
   (let ((do-toggle (and buffer-read-only even-if-read-only))
         (ess-prompt-rx (if inferior-ess-secondary-prompt
-                           (concat "^\\("
+                           (concat "^\\(\\("
                                    inferior-ess-prompt
                                    "\\)\\|\\("
                                    inferior-ess-secondary-prompt
-                                   "\\)")
+                                   "\\)\\)")
                          (concat "^" inferior-ess-prompt))))
     (save-excursion
       (if do-toggle (setq buffer-read-only nil))
