@@ -27,6 +27,7 @@
 ;;; Code:
 
 (eval-when-compile
+  (require 'tramp)
   (require 'cl))
 
 (defun ess-inside-string-or-comment-p (&optional pos)
@@ -35,11 +36,10 @@
   ;;FIXME (defun ess-calculate-indent ..)  can do that ...
   (interactive)
   (setq pos (or pos (point)))
-  (let ((pps
-         ;; (parse-partial-sexp (point-min) pos)
-         (syntax-ppss pos)))
-    ;; 3: string,  4: comment
-    (or (nth 3 pps) (nth 4 pps))))
+  (let ((ppss (syntax-ppss pos)))
+    (or (car (setq ppss (nthcdr 3 ppss)))
+        (car (setq ppss (cdr ppss)))
+        (nth 3 ppss))))
 
 
 (defun ess-inside-string-p (&optional pos)
@@ -1073,17 +1073,19 @@ queried for arguments.
         (setq args nil))
       (or args
           (cadr (assoc funname (process-get proc 'funargs-pre-cache)))
-          (with-current-buffer (ess-command (format ess-funargs-command
-                                                    (ess-quote-special-chars funname))
-                                            nil nil nil nil proc)
-            (goto-char (point-min))
-            (when (re-search-forward "(list" nil t)
-              (goto-char (match-beginning 0))
-              (setq args (ignore-errors (eval (read (current-buffer)))))
-              (if args
-                  (setcar args (cons (car args) (current-time)))))
-            ;; push even if nil
-            (puthash (substring-no-properties funname) args (process-get proc 'funargs-cache)))))))
+	  (and 
+	   (not (process-get proc 'busy))
+	   (with-current-buffer (ess-command (format ess-funargs-command
+						     (ess-quote-special-chars funname))
+					     nil nil nil nil proc)
+	     (goto-char (point-min))
+	     (when (re-search-forward "(list" nil t)
+	       (goto-char (match-beginning 0))
+	       (setq args (ignore-errors (eval (read (current-buffer)))))
+	       (if args
+		   (setcar args (cons (car args) (current-time)))))
+	     ;; push even if nil
+	     (puthash (substring-no-properties funname) args (process-get proc 'funargs-cache))))))))
 
 (defun ess-symbol-start ()
   "Get initial position for objects completion."
